import React, { useState, useEffect } from 'react';
import { Form, Modal, Button, Table, message, Input, InputNumber, Icon, Pagination } from 'antd';
import XForm, { FieldTypes } from '../../../components/XForm';
import request from '../../../utils/request';
import apis from '../../../services/apis';
import router from 'umi/router';
import Upload from '../../../components/uploadImage/Upload'
import { regFenToYuan } from '@/utils/money';

const { Column, ColumnGroup } = Table;

const formItemLayout = {
    labelCol: {
        xs: { span: 6 },
        sm: { span: 6 },
    },
    wrapperCol: {
        xs: { span: 18 },
        sm: { span: 18 },
    },
};

const SelectContact = props => {

    const [data, setData] = useState([]);
    const [visible, setVisible] = useState(false);
    const [group, setGroup] = useState({ groupId: undefined, groupName: '退款' })

    useEffect(() => {

    }, [props.value])


    const handleOk = (e) => {
        props.form.validateFieldsAndScroll((err, values) => {
            console.log(values, "valuesvaluesvaluesvaluesvaluesvaluesvalues")
            if (!err) {
                request({ ...apis.fund.accoutRefund, urlData: { id: props.accountId || '' }, data: { ...values, orgId: props.orgId } }).then((data) => {
                    message.info("操作成功")
                    setVisible(false)
                    props.onClick()
                })
            }
        });


    }

    const { getFieldDecorator } = props.form;
    const balance = regFenToYuan(props.realBalance)
    const regMoney = /^(\d+|\d+\.\d{1,2})$/;
    return (
        <div>
            <span onClick={() => setVisible(true)}>{group.groupName}</span>

            <Modal
                visible={visible}
                title="确认退款"
                onOk={() => handleOk()}
                onCancel={() => setVisible(false)}
                footer={[
                    <Button key="back" size="large" onClick={() => setVisible(false)}>取消</Button>,
                    <Button key="submit" type="primary" size="large" onClick={() => handleOk()}>确认</Button>,
                ]}
            >
                <div>
                    <p style={{ color: 'red' }}>请先进行线下实际退款操作后再执行线上退款存档</p>
                    <Form {...formItemLayout} >

                        <Form.Item label="退款金额" >
                            {getFieldDecorator('refundAmount', {
                                rules: [{ required: true, message: '退款金额不能为空' },
                                {
                                    validator: (rule, value, callback) => {

                                        callback(!regMoney.test(value) ? '金额最多两位小数' : value > balance.toString() ? '退款金额不能大于余额' : value < 0.01 ? '金额不得小于0.01' : undefined)

                                    }
                                }
                                ],
                            })(<Input type='number' placeholder="支持2位小数" addonAfter="元" />)}
                        </Form.Item>
                        <div style={{ marginBottom: '25px' }}><span style={{ width: '25%', display: 'inline-block', textAlign: 'right' }}>余额：</span>{balance}元</div>
                        <Form.Item label="退款凭证" help="可上传银行转账截图、微信退款订单等截图作为查账线索">
                            {getFieldDecorator('certificateList', {
                                rules: [{ required: false }],
                            })(
                                <Upload />,
                            )}
                        </Form.Item>
                    </Form>
                </div>

            </Modal>
        </div>
    )
}

const WrappedRegistrationForm = Form.create()(SelectContact);
export default WrappedRegistrationForm;